[libgsystem] localalloc: Fix variant builder unref
- From: Colin Walters <walters src gnome org>
- To: commits-list gnome org
- Cc:
- Subject: [libgsystem] localalloc: Fix variant builder unref
- Date: Wed, 14 Aug 2013 14:52:38 +0000 (UTC)
commit e9cf24540e0d6cb7e5f52b3facdea0b24a69e350
Author: Colin Walters <walters verbum org>
Date: Wed Aug 14 14:33:54 2013 +0200
localalloc: Fix variant builder unref
I will test my code before pushing.
I will test my code before pushing.
I will test my code before pushing.
gsystem-local-alloc.c | 4 ++--
gsystem-local-alloc.h | 6 +++---
2 files changed, 5 insertions(+), 5 deletions(-)
---
diff --git a/gsystem-local-alloc.c b/gsystem-local-alloc.c
index acac1a6..fa90654 100644
--- a/gsystem-local-alloc.c
+++ b/gsystem-local-alloc.c
@@ -108,9 +108,9 @@ gs_local_variant_iter_free (void *loc)
}
void
-gs_local_variant_builder_free (void *loc)
+gs_local_variant_builder_unref (void *loc)
{
- _gs_local_free(GVariantBuilder, g_variant_builder_free);
+ _gs_local_free(GVariantBuilder, g_variant_builder_unref);
}
void
diff --git a/gsystem-local-alloc.h b/gsystem-local-alloc.h
index 299b15e..9f855d2 100644
--- a/gsystem-local-alloc.h
+++ b/gsystem-local-alloc.h
@@ -34,7 +34,7 @@ void gs_local_free (void *loc);
void gs_local_obj_unref (void *loc);
void gs_local_variant_unref (void *loc);
void gs_local_variant_iter_free (void *loc);
-void gs_local_variant_builder_free (void *loc);
+void gs_local_variant_builder_unref (void *loc);
void gs_local_array_unref (void *loc);
void gs_local_ptrarray_unref (void *loc);
void gs_local_hashtable_unref (void *loc);
@@ -76,10 +76,10 @@ void gs_local_checksum_free (void *loc);
/**
* gs_free_variant_builder:
*
* Call g_variant_builder_free() on a variable location when it goes out of
* scope.
*/
-#define gs_free_variant_builder __attribute__ ((cleanup(gs_local_variant_builder_free)))
+#define gs_unref_variant_builder __attribute__ ((cleanup(gs_local_variant_builder_unref)))
/**
* gs_unref_array:
[
@@ -76,10 +76,10 @@ void gs_local_checksum_free (void *loc);
* gs_free_variant_builder:
*
- * Call g_variant_builder_free() on a variable location when it goes out of
+ * Call g_variant_builder_unref() on a variable location when it goes out of
* scope.
*/
Date Prev][
Date Next] [
Thread Prev][
Thread Next]
[
Thread Index]
[
Date Index]
[
Author Index]